
# Helmsman


<div align="center">

[![PyPI - Version](https://img.shields.io/pypi/v/helmsman.svg)](https://pypi.python.org/pypi/helmsman)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/helmsman.svg)](https://pypi.python.org/pypi/helmsman)
[![Tests](https://github.com/mrlyc/helmsman/workflows/tests/badge.svg)](https://github.com/mrlyc/helmsman/actions?workflow=tests)
[![Codecov](https://codecov.io/gh/mrlyc/helmsman/branch/main/graph/badge.svg)](https://codecov.io/gh/mrlyc/helmsman)
[![Read the Docs](https://readthedocs.org/projects/helmsman/badge/)](https://helmsman.readthedocs.io/)
[![PyPI - License](https://img.shields.io/pypi/l/helmsman.svg)](https://pypi.python.org/pypi/helmsman)

[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](https://www.contributor-covenant.org/version/2/0/code_of_conduct/)

</div>


Helmsman is a test framework for helm


* GitHub repo: <https://github.com/mrlyc/helmsman.git>
* Documentation: <https://helmsman.readthedocs.io>
* Free software: MIT


## Features

* TODO

## Quickstart

TODO

## Credits

This package was created with [Cookiecutter][cookiecutter] and the [fedejaure/cookiecutter-modern-pypackage][cookiecutter-modern-pypackage] project template.

[cookiecutter]: https://github.com/cookiecutter/cookiecutter
[cookiecutter-modern-pypackage]: https://github.com/fedejaure/cookiecutter-modern-pypackage
